DisGeNET over-representation analysis (ORA)
gly_enrich_dgn.RdThis function was deprecated because we decided to move all enrichment analysis functions
to the separate glyfun package, which has more features and better API design.
Perform DisGeNET ORA for protein UniProt accessions using DOSE::enrichDGN().
gly_enrich_dgn()accepts aglyexp::experiment()and extracts protein information from the "protein" column in the variable information tibble.gly_enrich_dgn_()accepts a character vector of UniProt IDs.
As DOSE::enrichDGN() only accepts Entrez IDs,
the UniProt IDs will be first transformed into Entrez IDs with clusterProfiler::bitr().
Usage
gly_enrich_dgn(
exp,
add_info = TRUE,
orgdb = "org.Hs.eg.db",
universe = NULL,
p_adj_method = "BH",
p_cutoff = 0.05,
q_cutoff = 0.2
)
gly_enrich_dgn_(
proteins,
orgdb = "org.Hs.eg.db",
universe = NULL,
p_adj_method = "BH",
p_cutoff = 0.05,
q_cutoff = 0.2
)Arguments
- exp
(Only for
gly_enrich_dgn()) Aglyexp::experiment()object.- add_info
A logical value. This parameter is included for API consistency but has no effect since enrichment results do not contain variable or sample columns. Only applicable to top-level APIs.
- orgdb
Passed to
OrgDbofclusterProfiler::bitr(). Organism database name (e.g., "org.Hs.eg.db" for human). Defaults to "org.Hs.eg.db".- universe
Background genes. If a character vector, it is expected to contain UniProt accession IDs; these will be converted to Entrez Gene IDs and then passed to
universeofDOSE::enrichDGN(). You can also provide aglyexp::experiment()object with "glycoproteomics" type. In this case all detected proteins in this experiment will be extracted as UniProt IDs, converted to Entrez IDs, and then passed touniverseofDOSE::enrichDGN().- p_adj_method
Passed to
pAdjustMethodofDOSE::enrichDGN().- p_cutoff
Passed to
pvalueCutoffofDOSE::enrichDGN().- q_cutoff
Passed to
qvalueCutoffofDOSE::enrichDGN().- proteins
(Only for
gly_enrich_dgn_()) A character vector of UniProt accession IDs.
Value
A list with three elements:
tidy_result: A tibble with enrichment results containing the following columns:id: Term IDdescription: Term descriptiongene_ratio: Ratio of genes in the term to total genes in the inputbg_ratio: Ratio of genes in the term to total genes in the backgroundp_val: Raw p-value from hypergeometric testp_adj: Adjusted p-valueq_value: Q-value (FDR)gene_id: Gene IDs in the term (separated by "/")count: Number of genes in the term
raw_result: The raw DOSE enrichResult objectmeta_data(only forgly_enrich_dgn()): A list containing metadata from the input experiment The list has classesglystats_dgn_ora_resandglystats_res.
Required packages
These functions require the following packages to be installed:
clusterProfilerfor ID conversionDOSEfor enrichment analysisorg.Hs.eg.dbfor human gene annotation or other OrgDb packages