Skip to contents

[Deprecated]

This function was deprecated because we decided to move all enrichment analysis functions to the separate glyfun package, which has more features and better API design.

Perform KEGG ORA for protein UniProt accessions using clusterProfiler::enrichKEGG().

  • gly_enrich_kegg() accepts a glyexp::experiment() and extracts protein information from the "protein" column in the variable information tibble.

  • gly_enrich_kegg_() accepts a character vector of UniProt IDs.

Usage

gly_enrich_kegg(
  exp,
  add_info = TRUE,
  organism = "hsa",
  universe = NULL,
  p_adj_method = "BH",
  p_cutoff = 0.05,
  q_cutoff = 0.2
)

gly_enrich_kegg_(
  proteins,
  keytype = "uniprot",
  organism = "hsa",
  universe = NULL,
  p_adj_method = "BH",
  p_cutoff = 0.05,
  q_cutoff = 0.2
)

Arguments

exp

(Only for gly_enrich_kegg()) A glyexp::experiment() object.

add_info

A logical value. This parameter is included for API consistency but has no effect since enrichment results do not contain variable or sample columns. Only applicable to top-level APIs.

organism

Passed to organism of clusterProfiler::enrichKEGG(). KEGG organism code (e.g., "hsa" for human, "mmu" for mouse). Defaults to "hsa".

universe

Background genes. If a character vector, directly passed to universe of clusterProfiler::enrichKEGG(). You can also provide a glyexp::experiment() object with "glycoproteomics" type. In this case all detected proteins in this experiment will be extracted and passed to universe of clusterProfiler::enrichKEGG().

p_adj_method

Passed to pAdjustMethod of clusterProfiler::enrichKEGG().

p_cutoff

Passed to pvalueCutoff of clusterProfiler::enrichKEGG().

q_cutoff

Passed to qvalueCutoff of clusterProfiler::enrichKEGG().

proteins

(Only for gly_enrich_kegg_()) A character vector of UniProt accession IDs.

keytype

Passed to keyType of clusterProfiler::enrichKEGG(). Defaults to "uniprot".

Value

A list with three elements:

  • tidy_result: A tibble with enrichment results containing the following columns:

    • id: Term ID (e.g., hsa:XXXXX)

    • description: Term description

    • gene_ratio: Ratio of genes in the term to total genes in the input

    • bg_ratio: Ratio of genes in the term to total genes in the background

    • p_val: Raw p-value from hypergeometric test

    • p_adj: Adjusted p-value

    • q_value: Q-value (FDR)

    • gene_id: Gene IDs in the term (separated by "/")

    • count: Number of genes in the term

  • raw_result: The raw clusterProfiler enrichResult object

  • meta_data (only for gly_enrich_kegg()): A list containing metadata from the input experiment The list has classes glystats_kegg_ora_res and glystats_res.

Required packages

These functions require the following packages to be installed:

  • clusterProfiler for enrichment analysis