GO over-representation analysis (ORA)
gly_enrich_go.RdThis function was deprecated because we decided to move all enrichment analysis functions
to the separate glyfun package, which has more features and better API design.
Perform GO ORA for protein UniProt accessions using clusterProfiler::enrichGO().
gly_enrich_go()accepts aglyexp::experiment()and extracts protein information from the "protein" column in the variable information tibble.gly_enrich_go_()accepts a character vector of UniProt IDs.
Usage
gly_enrich_go(
exp,
add_info = TRUE,
orgdb = "org.Hs.eg.db",
ont = "MF",
universe = NULL,
p_adj_method = "BH",
p_cutoff = 0.05,
q_cutoff = 0.2
)
gly_enrich_go_(
proteins,
orgdb = "org.Hs.eg.db",
keytype = "UNIPROT",
ont = "MF",
universe = NULL,
p_adj_method = "BH",
p_cutoff = 0.05,
q_cutoff = 0.2
)Arguments
- exp
(Only for
gly_enrich_go()) Aglyexp::experiment()object.- add_info
A logical value. This parameter is included for API consistency but has no effect since enrichment results do not contain variable or sample columns. Only applicable to top-level APIs.
- orgdb
Passed to
OrgDbofclusterProfiler::enrichGO().- ont
Passed to
ontofclusterProfiler::enrichGO(). "BP", "MF", "CC", or "ALL". Defaults to "MF".- universe
Background genes. If a character vector, directly passed to
universeofclusterProfiler::enrichGO(). You can also provide aglyexp::experiment()object with "glycoproteomics" type. In this case all detected proteins in this experiment will be extracted and passed touniverseofclusterProfiler::enrichGO().- p_adj_method
Passed to
pAdjustMethodofclusterProfiler::enrichGO().- p_cutoff
Passed to
pvalueCutoffofclusterProfiler::enrichGO().- q_cutoff
Passed to
qvalueCutoffofclusterProfiler::enrichGO().- proteins
(Only for
gly_enrich_go_()) A character vector of UniProt accession IDs.- keytype
Passed to
keyTypeofclusterProfiler::enrichGO().
Value
A list with three elements:
tidy_result: A tibble with enrichment results containing the following columns:id: Term IDdescription: Term descriptiongene_ratio: Ratio of genes in the term to total genes in the inputbg_ratio: Ratio of genes in the term to total genes in the backgroundp_val: Raw p-value from hypergeometric testp_adj: Adjusted p-valueq_value: Q-value (FDR)gene_id: Gene IDs in the term (separated by "/")count: Number of genes in the term
raw_result: The raw clusterProfiler enrichResult objectmeta_data(only forgly_enrich_go()): A list containing metadata from the input experiment The list has classesglystats_go_ora_resandglystats_res.
Required packages
These functions require the following packages to be installed:
clusterProfilerfor enrichment analysisorg.Hs.eg.dbfor human gene annotation or other OrgDb packages