KEGG over-representation analysis (ORA)
gly_enrich_kegg.RdThis function was deprecated because we decided to move all enrichment analysis functions
to the separate glyfun package, which has more features and better API design.
Perform KEGG ORA for protein UniProt accessions using clusterProfiler::enrichKEGG().
gly_enrich_kegg()accepts aglyexp::experiment()and extracts protein information from the "protein" column in the variable information tibble.gly_enrich_kegg_()accepts a character vector of UniProt IDs.
Usage
gly_enrich_kegg(
exp,
add_info = TRUE,
organism = "hsa",
universe = NULL,
p_adj_method = "BH",
p_cutoff = 0.05,
q_cutoff = 0.2
)
gly_enrich_kegg_(
proteins,
keytype = "uniprot",
organism = "hsa",
universe = NULL,
p_adj_method = "BH",
p_cutoff = 0.05,
q_cutoff = 0.2
)Arguments
- exp
(Only for
gly_enrich_kegg()) Aglyexp::experiment()object.- add_info
A logical value. This parameter is included for API consistency but has no effect since enrichment results do not contain variable or sample columns. Only applicable to top-level APIs.
- organism
Passed to
organismofclusterProfiler::enrichKEGG(). KEGG organism code (e.g., "hsa" for human, "mmu" for mouse). Defaults to "hsa".- universe
Background genes. If a character vector, directly passed to
universeofclusterProfiler::enrichKEGG(). You can also provide aglyexp::experiment()object with "glycoproteomics" type. In this case all detected proteins in this experiment will be extracted and passed touniverseofclusterProfiler::enrichKEGG().- p_adj_method
Passed to
pAdjustMethodofclusterProfiler::enrichKEGG().- p_cutoff
Passed to
pvalueCutoffofclusterProfiler::enrichKEGG().- q_cutoff
Passed to
qvalueCutoffofclusterProfiler::enrichKEGG().- proteins
(Only for
gly_enrich_kegg_()) A character vector of UniProt accession IDs.- keytype
Passed to
keyTypeofclusterProfiler::enrichKEGG(). Defaults to "uniprot".
Value
A list with three elements:
tidy_result: A tibble with enrichment results containing the following columns:id: Term ID (e.g., hsa:XXXXX)description: Term descriptiongene_ratio: Ratio of genes in the term to total genes in the inputbg_ratio: Ratio of genes in the term to total genes in the backgroundp_val: Raw p-value from hypergeometric testp_adj: Adjusted p-valueq_value: Q-value (FDR)gene_id: Gene IDs in the term (separated by "/")count: Number of genes in the term
raw_result: The raw clusterProfiler enrichResult objectmeta_data(only forgly_enrich_kegg()): A list containing metadata from the input experiment The list has classesglystats_kegg_ora_resandglystats_res.
Required packages
These functions require the following packages to be installed:
clusterProfilerfor enrichment analysis