WikiPathways over-representation analysis (ORA)
gly_enrich_wikipathways.RdThis function was deprecated because we decided to move all enrichment analysis functions
to the separate glyfun package, which has more features and better API design.
Perform WikiPathways ORA for protein UniProt accessions using clusterProfiler::enrichWP().
gly_enrich_wikipathways()accepts aglyexp::experiment()and extracts protein information from the "protein" column in the variable information tibble.gly_enrich_wikipathways_()accepts a character vector of UniProt IDs.
As clusterProfiler::enrichWP() only accepts Entrez IDs,
the UniProt IDs will be first transformed into Entrez IDs with clusterProfiler::bitr().
Usage
gly_enrich_wikipathways(
exp,
add_info = TRUE,
organism = "Homo sapiens",
orgdb = "org.Hs.eg.db",
universe = NULL,
p_adj_method = "BH",
p_cutoff = 0.05,
q_cutoff = 0.2
)
gly_enrich_wikipathways_(
proteins,
organism = "Homo sapiens",
orgdb = "org.Hs.eg.db",
universe = NULL,
p_adj_method = "BH",
p_cutoff = 0.05,
q_cutoff = 0.2
)Arguments
- exp
(Only for
gly_enrich_wikipathways()) Aglyexp::experiment()object.- add_info
A logical value. This parameter is included for API consistency but has no effect since enrichment results do not contain variable or sample columns. Only applicable to top-level APIs.
- organism
Passed to
organismofclusterProfiler::enrichWP(). Species name (e.g., "Homo sapiens", "Mus musculus", "Rattus norvegicus"). Defaults to "Homo sapiens".- orgdb
Passed to
OrgDbofclusterProfiler::bitr(). Organism database name (e.g., "org.Hs.eg.db" for human). Defaults to "org.Hs.eg.db".- universe
Background genes. If a character vector, it is expected to contain UniProt accession IDs; these will be converted to Entrez Gene IDs and then passed to
universeofclusterProfiler::enrichWP(). You can also provide aglyexp::experiment()object with "glycoproteomics" type. In this case all detected proteins in this experiment will be extracted as UniProt IDs, converted to Entrez IDs, and then passed touniverseofclusterProfiler::enrichWP().- p_adj_method
Passed to
pAdjustMethodofclusterProfiler::enrichWP().- p_cutoff
Passed to
pvalueCutoffofclusterProfiler::enrichWP().- q_cutoff
Passed to
qvalueCutoffofclusterProfiler::enrichWP().- proteins
(Only for
gly_enrich_wikipathways_()) A character vector of UniProt accession IDs.
Value
A list with three elements:
tidy_result: A tibble with enrichment results containing the following columns:id: Term ID (e.g., WPXXXXX)description: Term descriptiongene_ratio: Ratio of genes in the term to total genes in the inputbg_ratio: Ratio of genes in the term to total genes in the backgroundp_val: Raw p-value from hypergeometric testp_adj: Adjusted p-valueq_value: Q-value (FDR)gene_id: Gene IDs in the term (separated by "/")count: Number of genes in the term
raw_result: The raw clusterProfiler enrichResult objectmeta_data(only forgly_enrich_wikipathways()): A list containing metadata from the input experiment The list has classesglystats_wikipathways_ora_resandglystats_res.
Required packages
These functions require the following packages to be installed:
clusterProfilerfor enrichment analysis and ID conversionorg.Hs.eg.dbfor human gene annotation or other OrgDb packages