t-Distributed Stochastic Neighbor Embedding (t-SNE)
gly_tsne.RdPerform t-SNE dimensionality reduction on the expression data.
The function uses Rtsne::Rtsne() to perform t-SNE analysis.
Arguments
- exp
A
glyexp::GlycomicSE()orglyexp::GlycoproteomicSE()object, or anotherSummarizedExperimentcontaining an expression matrix and sample information.- dims
Number of output dimensions. Default is 2.
- perplexity
Perplexity parameter for t-SNE. Default is 30.
- add_info
A logical value. If TRUE (default), sample information from the experiment will be added to the result tibble. If FALSE, only the t-SNE coordinates are returned.
- ...
Additional arguments passed to
Rtsne::Rtsne().
Value
A list with three elements:
tidy_result: A tibble with t-SNE coordinates containing the following columns:sample: Sample nametsne1: First t-SNE dimensiontsne2: Second t-SNE dimension
raw_result: The raw Rtsne objectmeta_data: A list containing metadata from the input experiment The list has classesglystats_tsne_resandglystats_res.